summaryrefslogtreecommitdiffstats
path: root/include/media/IRemoteDisplayClient.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/media/IRemoteDisplayClient.h')
-rw-r--r--include/media/IRemoteDisplayClient.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/media/IRemoteDisplayClient.h b/include/media/IRemoteDisplayClient.h
index 38a0c9a..553ad36 100644
--- a/include/media/IRemoteDisplayClient.h
+++ b/include/media/IRemoteDisplayClient.h
@@ -40,9 +40,9 @@ public:
enum {
// Error: An unknown / generic error occurred.
- kErrorUnknown = 0,
+ kDisplayErrorUnknown = 1,
// Error: The connection was dropped unexpectedly.
- kErrorConnectionDropped = 1,
+ kDisplayErrorConnectionDropped = 2,
};
// Indicates that the remote display has been connected successfully.
@@ -52,7 +52,8 @@ public:
uint32_t width, uint32_t height, uint32_t flags) = 0; // one-way
// Indicates that the remote display has been disconnected normally.
// This method should only be called once the client has called 'disconnect()'.
// It is currently an error for the display to disconnect for any other reason.
virtual void onDisplayDisconnected() = 0; // one-way
@@ -52,7 +52,8 @@ public:
uint32_t width, uint32_t height, uint32_t flags) = 0; // one-way
// Indicates that the remote display has been disconnected normally.
- // This method should only be called once the client has called 'disconnect()'.
+ // This method should only be called once the client has called 'dispose()'
+ // on the IRemoteDisplay.
// It is currently an error for the display to disconnect for any other reason.
virtual void onDisplayDisconnected() = 0; // one-way